<?php
/**
 * Plugin Name: ebl_buildJs
 * Description: Outputs script tags for JavaScript files in the named theme's JS directory.
 * Author: Eric B. Limegrover
 * https://ericlimegrover.com/projects/
 * Version: 1.2
 */

// Register the new tag with Textpattern
\Txp::get('\Textpattern\Tag\Registry')->register('ebl_buildJs');

/**
 * Outputs script tags for JavaScript files in the theme's JS directory.
 *
 * @param array  $atts  Attributes passed to the tag.
 * @param string $thing Content enclosed by the tag (optional).
 *
 * @return string HTML script tags for JS files.
 */

function ebl_buildJs($atts, $thing = null) {
    global $path_to_site, $pretext;

    $skin_dir = get_pref('skin_dir'); // Correct function name

    // Define and sanitize attributes
    $atts = lAtts([
        'theme' => '',
        'directory' => '',
        'name' => '', // Singular file name to load
        'exclude' => '' // File to exclude from bulk loading
    ], $atts);

    // Check if theme is provided
    if (empty($atts['theme'])) {
        return '<!-- Error: No theme name specified -->';
    }

    // Construct the theme path
    $theme_path = $path_to_site . DS . $skin_dir . '/' . $atts['theme'] . '/' . $atts['directory'];

    // Validate the directory exists
    if (!@is_dir($theme_path)) {
        return "<!-- Error: Specified directory does not exist: [$theme_path] -->";
    }

    // Handle singular file loading
    if (!empty($atts['name'])) {
        $atts['name'] = preg_replace('/\.js$/', '', $atts['name']); // Remove .js if present
        $file_name = $theme_path . '/' . $atts['name'] . '.js';
        if (file_exists($file_name)) {
            return '<script src="' . hu . $skin_dir . '/' . $atts['theme'] . '/' . $atts['directory'] . '/' . $atts['name'] . '.js"></script>' . "\n";
        } else {
            return "<!-- Error: Specified file does not exist: [{$atts['name']}.js] -->";
        }
    }

    // Retrieve .js files for bulk loading
    $files = @glob($theme_path . '/*.js');
    if ($files) {
        natsort($files); // Sort files naturally (e.g., "1.js", "2.js", "10.js")
    }

    if ($files === false || empty($files)) {
        return "<!-- Error: No JS files found in directory: [$theme_path] -->";
    }

    // Handle exclusion
    $exclude = $atts['exclude'] ? explode(',', $atts['exclude']) : [];
    $exclude = array_map('trim', $exclude);

    // Build script tags
    $output = '';
    foreach ($files as $file) {
        $filename = preg_replace('/\.js$/', '', basename($file));
        if (in_array($filename, $exclude)) {
            continue;
        }
        $output .= '<script src="' . hu . $skin_dir . '/' . $atts['theme'] . '/' . $atts['directory'] . '/' . basename($file) . '"></script>' . "\n";
    }

    return $output;
}